==> esp8266-0.5.0.crate: esp8266-0.5.0/src/slc/slc_token0.rs <==
#[doc = "Register `SLC_TOKEN0` reader"]
pub struct R(crate::R<SLC_TOKEN0_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<SLC_TOKEN0_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<SLC_TOKEN0_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<SLC_TOKEN0_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `SLC_TOKEN0` writer"]
pub struct W(crate::W<SLC_TOKEN0_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<SLC_TOKEN0_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<SLC_TOKEN0_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<SLC_TOKEN0_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `SLC_TOKEN0` reader - "]
pub struct SLC_TOKEN0_R(crate::FieldReader<u16, u16>);
impl SLC_TOKEN0_R {
    #[inline(always)]
    pub(crate) fn new(bits: u16) -> Self {
        SLC_TOKEN0_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SLC_TOKEN0_R {
    type Target = crate::FieldReader<u16, u16>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `SLC_TOKEN0` writer - "]
pub struct SLC_TOKEN0_W<'a> {
    w: &'a mut W,
}
impl<'a> SLC_TOKEN0_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u16) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x0fff << 16)) | ((value as u32 & 0x0fff) << 16);
        self.w
    }
}
#[doc = "Field `SLC_TOKEN0_LOCAL_INC_MORE` reader - "]
pub struct SLC_TOKEN0_LOCAL_INC_MORE_R(crate::FieldReader<bool, bool>);
impl SLC_TOKEN0_LOCAL_INC_MORE_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        SLC_TOKEN0_LOCAL_INC_MORE_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SLC_TOKEN0_LOCAL_INC_MORE_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `SLC_TOKEN0_LOCAL_INC_MORE` writer - "]
pub struct SLC_TOKEN0_LOCAL_INC_MORE_W<'a> {
    w: &'a mut W,
}
impl<'a> SLC_TOKEN0_LOCAL_INC_MORE_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
        self.w
    }
}
#[doc = "Field `SLC_TOKEN0_LOCAL_INC` reader - "]
pub struct SLC_TOKEN0_LOCAL_INC_R(crate::FieldReader<bool, bool>);
impl SLC_TOKEN0_LOCAL_INC_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        SLC_TOKEN0_LOCAL_INC_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SLC_TOKEN0_LOCAL_INC_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `SLC_TOKEN0_LOCAL_INC` writer - "]
pub struct SLC_TOKEN0_LOCAL_INC_W<'a> {
    w: &'a mut W,
}
impl<'a> SLC_TOKEN0_LOCAL_INC_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
        self.w
    }
}
#[doc = "Field `SLC_TOKEN0_LOCAL_WR` reader - "]
pub struct SLC_TOKEN0_LOCAL_WR_R(crate::FieldReader<bool, bool>);
impl SLC_TOKEN0_LOCAL_WR_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        SLC_TOKEN0_LOCAL_WR_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SLC_TOKEN0_LOCAL_WR_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `SLC_TOKEN0_LOCAL_WR` writer - "]
pub struct SLC_TOKEN0_LOCAL_WR_W<'a> {
    w: &'a mut W,
}
impl<'a> SLC_TOKEN0_LOCAL_WR_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
        self.w
    }
}
#[doc = "Field `SLC_TOKEN0_LOCAL_WDATA` reader - "]
pub struct SLC_TOKEN0_LOCAL_WDATA_R(crate::FieldReader<u16, u16>);
impl SLC_TOKEN0_LOCAL_WDATA_R {
    #[inline(always)]
    pub(crate) fn new(bits: u16) -> Self {
        SLC_TOKEN0_LOCAL_WDATA_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SLC_TOKEN0_LOCAL_WDATA_R {
    type Target = crate::FieldReader<u16, u16>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `SLC_TOKEN0_LOCAL_WDATA` writer - "]
pub struct SLC_TOKEN0_LOCAL_WDATA_W<'a> {
    w: &'a mut W,
}
impl<'a> SLC_TOKEN0_LOCAL_WDATA_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u16) -> &'a mut W {
        self.w.bits = (self.w.bits & !0x0fff) | (value as u32 & 0x0fff);
        self.w
    }
}
impl R {
    #[doc = "Bits 16:27"]
    #[inline(always)]
    pub fn slc_token0(&self) -> SLC_TOKEN0_R {
        SLC_TOKEN0_R::new(((self.bits >> 16) & 0x0fff) as u16)
    }
    #[doc = "Bit 14"]
    #[inline(always)]
    pub fn slc_token0_local_inc_more(&self) -> SLC_TOKEN0_LOCAL_INC_MORE_R {
        SLC_TOKEN0_LOCAL_INC_MORE_R::new(((self.bits >> 14) & 0x01) != 0)
    }
    #[doc = "Bit 13"]
    #[inline(always)]
    pub fn slc_token0_local_inc(&self) -> SLC_TOKEN0_LOCAL_INC_R {
        SLC_TOKEN0_LOCAL_INC_R::new(((self.bits >> 13) & 0x01) != 0)
    }
    #[doc = "Bit 12"]
    #[inline(always)]
    pub fn slc_token0_local_wr(&self) -> SLC_TOKEN0_LOCAL_WR_R {
        SLC_TOKEN0_LOCAL_WR_R::new(((self.bits >> 12) & 0x01) != 0)
    }
    #[doc = "Bits 0:11"]
    #[inline(always)]
    pub fn slc_token0_local_wdata(&self) -> SLC_TOKEN0_LOCAL_WDATA_R {
        SLC_TOKEN0_LOCAL_WDATA_R::new((self.bits & 0x0fff) as u16)
    }
}
impl W {
    #[doc = "Bits 16:27"]
    #[inline(always)]
    pub fn slc_token0(&mut self) -> SLC_TOKEN0_W {
        SLC_TOKEN0_W { w: self }
    }
    #[doc = "Bit 14"]
    #[inline(always)]
    pub fn slc_token0_local_inc_more(&mut self) -> SLC_TOKEN0_LOCAL_INC_MORE_W {
        SLC_TOKEN0_LOCAL_INC_MORE_W { w: self }
    }
    #[doc = "Bit 13"]
    #[inline(always)]
    pub fn slc_token0_local_inc(&mut self) -> SLC_TOKEN0_LOCAL_INC_W {
        SLC_TOKEN0_LOCAL_INC_W { w: self }
    }
    #[doc = "Bit 12"]
    #[inline(always)]
    pub fn slc_token0_local_wr(&mut self) -> SLC_TOKEN0_LOCAL_WR_W {
        SLC_TOKEN0_LOCAL_WR_W { w: self }
    }
    #[doc = "Bits 0:11"]
    #[inline(always)]
    pub fn slc_token0_local_wdata(&mut self) -> SLC_TOKEN0_LOCAL_WDATA_W {
        SLC_TOKEN0_LOCAL_WDATA_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "SLC_TOKEN0\n\nThis register you can [`read`]
(crate::generic::Reg::read), [`write_with_zero`]
(crate::generic::Reg::write_with_zero), [`reset`]
(crate::generic::Reg::reset), [`write`]
(crate::generic::Reg::write), [`modify`]
(crate::generic::Reg::modify). See [API]
(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [slc_token0]
(index.html) module"]
pub struct SLC_TOKEN0_SPEC;
impl crate::RegisterSpec for SLC_TOKEN0_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [slc_token0::R]
(R) reader structure"]
impl crate::Readable for SLC_TOKEN0_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [slc_token0::W]
(W) writer structure"]
impl crate::Writable for SLC_TOKEN0_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets SLC_TOKEN0 to value 0"]
impl crate::Resettable for SLC_TOKEN0_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> esp8266-0.6.0.crate: esp8266-0.6.0/src/slc/slc_token0.rs <==
#[doc = "Register `SLC_TOKEN0` reader"]
pub struct R(crate::R<SLC_TOKEN0_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<SLC_TOKEN0_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<SLC_TOKEN0_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<SLC_TOKEN0_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `SLC_TOKEN0` writer"]
pub struct W(crate::W<SLC_TOKEN0_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<SLC_TOKEN0_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<SLC_TOKEN0_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<SLC_TOKEN0_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `SLC_TOKEN0` reader - "]
pub struct SLC_TOKEN0_R(crate::FieldReader<u16, u16>);
impl SLC_TOKEN0_R {
    #[inline(always)]
    pub(crate) fn new(bits: u16) -> Self {
        SLC_TOKEN0_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SLC_TOKEN0_R {
    type Target = crate::FieldReader<u16, u16>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `SLC_TOKEN0` writer - "]
pub struct SLC_TOKEN0_W<'a> {
    w: &'a mut W,
}
impl<'a> SLC_TOKEN0_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u16) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x0fff << 16)) | ((value as u32 & 0x0fff) << 16);
        self.w
    }
}
#[doc = "Field `SLC_TOKEN0_LOCAL_INC_MORE` reader - "]
pub struct SLC_TOKEN0_LOCAL_INC_MORE_R(crate::FieldReader<bool, bool>);
impl SLC_TOKEN0_LOCAL_INC_MORE_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        SLC_TOKEN0_LOCAL_INC_MORE_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SLC_TOKEN0_LOCAL_INC_MORE_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `SLC_TOKEN0_LOCAL_INC_MORE` writer - "]
pub struct SLC_TOKEN0_LOCAL_INC_MORE_W<'a> {
    w: &'a mut W,
}
impl<'a> SLC_TOKEN0_LOCAL_INC_MORE_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(1 << 14)) | ((value as u32 & 1) << 14);
        self.w
    }
}
#[doc = "Field `SLC_TOKEN0_LOCAL_INC` reader - "]
pub struct SLC_TOKEN0_LOCAL_INC_R(crate::FieldReader<bool, bool>);
impl SLC_TOKEN0_LOCAL_INC_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        SLC_TOKEN0_LOCAL_INC_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SLC_TOKEN0_LOCAL_INC_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `SLC_TOKEN0_LOCAL_INC` writer - "]
pub struct SLC_TOKEN0_LOCAL_INC_W<'a> {
    w: &'a mut W,
}
impl<'a> SLC_TOKEN0_LOCAL_INC_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
        self.w
    }
}
#[doc = "Field `SLC_TOKEN0_LOCAL_WR` reader - "]
pub struct SLC_TOKEN0_LOCAL_WR_R(crate::FieldReader<bool, bool>);
impl SLC_TOKEN0_LOCAL_WR_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        SLC_TOKEN0_LOCAL_WR_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SLC_TOKEN0_LOCAL_WR_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `SLC_TOKEN0_LOCAL_WR` writer - "]
pub struct SLC_TOKEN0_LOCAL_WR_W<'a> {
    w: &'a mut W,
}
impl<'a> SLC_TOKEN0_LOCAL_WR_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(1 << 12)) | ((value as u32 & 1) << 12);
        self.w
    }
}
#[doc = "Field `SLC_TOKEN0_LOCAL_WDATA` reader - "]
pub struct SLC_TOKEN0_LOCAL_WDATA_R(crate::FieldReader<u16, u16>);
impl SLC_TOKEN0_LOCAL_WDATA_R {
    #[inline(always)]
    pub(crate) fn new(bits: u16) -> Self {
        SLC_TOKEN0_LOCAL_WDATA_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SLC_TOKEN0_LOCAL_WDATA_R {
    type Target = crate::FieldReader<u16, u16>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `SLC_TOKEN0_LOCAL_WDATA` writer - "]
pub struct SLC_TOKEN0_LOCAL_WDATA_W<'a> {
    w: &'a mut W,
}
impl<'a> SLC_TOKEN0_LOCAL_WDATA_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u16) -> &'a mut W {
        self.w.bits = (self.w.bits & !0x0fff) | (value as u32 & 0x0fff);
        self.w
    }
}
impl R {
    #[doc = "Bits 16:27"]
    #[inline(always)]
    pub fn slc_token0(&self) -> SLC_TOKEN0_R {
        SLC_TOKEN0_R::new(((self.bits >> 16) & 0x0fff) as u16)
    }
    #[doc = "Bit 14"]
    #[inline(always)]
    pub fn slc_token0_local_inc_more(&self) -> SLC_TOKEN0_LOCAL_INC_MORE_R {
        SLC_TOKEN0_LOCAL_INC_MORE_R::new(((self.bits >> 14) & 1) != 0)
    }
    #[doc = "Bit 13"]
    #[inline(always)]
    pub fn slc_token0_local_inc(&self) -> SLC_TOKEN0_LOCAL_INC_R {
        SLC_TOKEN0_LOCAL_INC_R::new(((self.bits >> 13) & 1) != 0)
    }
    #[doc = "Bit 12"]
    #[inline(always)]
    pub fn slc_token0_local_wr(&self) -> SLC_TOKEN0_LOCAL_WR_R {
        SLC_TOKEN0_LOCAL_WR_R::new(((self.bits >> 12) & 1) != 0)
    }
    #[doc = "Bits 0:11"]
    #[inline(always)]
    pub fn slc_token0_local_wdata(&self) -> SLC_TOKEN0_LOCAL_WDATA_R {
        SLC_TOKEN0_LOCAL_WDATA_R::new((self.bits & 0x0fff) as u16)
    }
}
impl W {
    #[doc = "Bits 16:27"]
    #[inline(always)]
    pub fn slc_token0(&mut self) -> SLC_TOKEN0_W {
        SLC_TOKEN0_W { w: self }
    }
    #[doc = "Bit 14"]
    #[inline(always)]
    pub fn slc_token0_local_inc_more(&mut self) -> SLC_TOKEN0_LOCAL_INC_MORE_W {
        SLC_TOKEN0_LOCAL_INC_MORE_W { w: self }
    }
    #[doc = "Bit 13"]
    #[inline(always)]
    pub fn slc_token0_local_inc(&mut self) -> SLC_TOKEN0_LOCAL_INC_W {
        SLC_TOKEN0_LOCAL_INC_W { w: self }
    }
    #[doc = "Bit 12"]
    #[inline(always)]
    pub fn slc_token0_local_wr(&mut self) -> SLC_TOKEN0_LOCAL_WR_W {
        SLC_TOKEN0_LOCAL_WR_W { w: self }
    }
    #[doc = "Bits 0:11"]
    #[inline(always)]
    pub fn slc_token0_local_wdata(&mut self) -> SLC_TOKEN0_LOCAL_WDATA_W {
        SLC_TOKEN0_LOCAL_WDATA_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "SLC_TOKEN0\n\nThis register you can [`read`]
(crate::generic::Reg::read), [`write_with_zero`]
(crate::generic::Reg::write_with_zero), [`reset`]
(crate::generic::Reg::reset), [`write`]
(crate::generic::Reg::write), [`modify`]
(crate::generic::Reg::modify). See [API]
(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [slc_token0]
(index.html) module"]
pub struct SLC_TOKEN0_SPEC;
impl crate::RegisterSpec for SLC_TOKEN0_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [slc_token0::R]
(R) reader structure"]
impl crate::Readable for SLC_TOKEN0_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [slc_token0::W]
(W) writer structure"]
impl crate::Writable for SLC_TOKEN0_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets SLC_TOKEN0 to value 0"]
impl crate::Resettable for SLC_TOKEN0_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
